@@ -172,16 +172,18 @@ def parameterInit(parameters):
         rawDataHelper.calGradPoints(parameters)
     if parameters["rtRange"] is None:
         parameters["rtRange"] = (parameters["timePoints"][0], parameters["timePoints"][-1])
-    if parameters["isChangable"] is False:
-        parameters["isChangable"] = np.ones(len(parameters["timePoints"]), dtype=bool)
-        parameters["isChangable"][np.array([0,1,-1])] = False
-    
-    else:
-        parameters["isChangable"] = np.ones(len(parameters["timePoints"]), dtype=bool)
-        parameters["isChangable"][np.array([0,-1])] = False
+    # if parameters["isChangable"] is not a numpy array
+    if not isinstance(parameters["isChangable"], np.ndarray):
+        if parameters["isChangable"] is False:
+            parameters["isChangable"] = np.ones(len(parameters["timePoints"]), dtype=bool)
+            parameters["isChangable"][np.array([0,1,-1])] = False
+        
+        else:
+            parameters["isChangable"] = np.ones(len(parameters["timePoints"]), dtype=bool)
+            parameters["isChangable"][np.array([0,-1])] = False
 
 
-def saveParameters(parameters):
+def saveParameters(parameters, fileName="parameters"):
     '''
     This function is used to save the project using pickle.
 
@@ -189,10 +191,13 @@ def saveParameters(parameters):
     ----------------------------------------------------------
     parameters: dict
         Global parameters.
+    fileName: str
+        The name of the file to save the parameters.
     '''
 
     # Save the parameters
-    with open("parameters.pkl", "wb") as f:
+    fileName = fileName + ".pkl"
+    with open(fileName, "wb") as f:
         pickle.dump(parameters, f)
 
 
