@@ -356,8 +356,8 @@ class MSData:
         plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1)
         # set aspect ratio
         plt.gca().set_aspect(aspect)
-        plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=5)
-        plt.ylabel("Intensity, %", fontname='Arial', fontsize=fontsize, labelpad=5)
+        plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=2)
+        plt.ylabel("Intensity, %", fontname='Arial', fontsize=fontsize, labelpad=2)
         plt.xticks(fontname='Arial', fontsize=fontsize)
         plt.yticks(fontname='Arial', fontsize=fontsize)
         plt.savefig(fname=pltName, bbox_inches='tight')
@@ -855,7 +855,7 @@ def outputConfig(name, timePoints, gradient):
     df.to_csv(fname, index=False)
 
 
-def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600, figsize=(6, 4)):
+def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600, figsize=(6, 4), **kwargs):
     """
     Function to output the gradient figure in png.
 
@@ -877,8 +877,8 @@ def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600, figsize=
 
     plt.figure(figsize=figsize, dpi=dpi)
     plt.plot(timePoints, gradient, color="black", linewidth=1)
-    plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=2)
-    plt.ylabel("Mobile phase, %", fontname='Arial', fontsize=fontsize, labelpad=2)
+    plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=5)
+    plt.ylabel("Mobile phase, %", fontname='Arial', fontsize=fontsize, labelpad=5)
     plt.xticks(fontname='Arial', fontsize=fontsize)
     plt.yticks(np.arange(0, 120, 20), fontname='Arial', fontsize=fontsize)
     plt.savefig(fname=name, bbox_inches='tight')
